<?php
/**
 * @author Shawn P. Duncan <code@sd.shawnduncan.org>
 * @date   4/29/17,  11:25 AM
 *
 * Copyright 2017 by Shawn P. Duncan.  This code is
 * released under the GNU General Public License.
 * Which means that it is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * http://www.gnu.org/licenses/gpl.html
 */

namespace Drupal\formassembly\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining FormAssembly Form entities.
 *
 * @ingroup formassembly
 */
interface FormAssemblyEntityInterface extends  ContentEntityInterface, EntityChangedInterface {

  // Add get/set methods for your configuration properties here.

  /**
   * Gets the FormAssembly Form name.
   *
   * @return string
   *   Name of the FormAssembly Form.
   */
  public function getName();

  /**
   * Sets the FormAssembly Form name.
   *
   * @param string $name
   *   The FormAssembly Form name.
   *
   * @return \Drupal\formassembly\Entity\FormAssemblyEntityInterface
   *   The called FormAssembly Form entity.
   */
  public function setName($name);

  /**
   * Gets the FormAssembly Form creation timestamp.
   *
   * @return int
   *   Creation timestamp of the FormAssembly Form.
   */
  public function getCreatedTime();

  /**
   * Sets the FormAssembly Form creation timestamp.
   *
   * @param int $timestamp
   *   The FormAssembly Form creation timestamp.
   *
   * @return \Drupal\formassembly\Entity\FormAssemblyEntityInterface
   *   The called FormAssembly Form entity.
   */
  public function setCreatedTime($timestamp);

}
