<?php
/**
 * @author Shawn P. Duncan <code@sd.shawnduncan.org>
 * @date   7/15/18,  4:19 PM
 *
 * @brief
 *
 * Copyright 2018 by Shawn P. Duncan.  This code is
 * released under the GNU General Public License.
 * Which means that it is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 * http://www.gnu.org/licenses/gpl.html
 */

namespace Drupal\formassembly;


use Drupal\Core\Database\InvalidQueryException;
use Drupal\Core\Entity\Sql\SqlContentEntityStorage;

class FormAssemblyStorage extends SqlContentEntityStorage {

  /**
   * Returns the entity id and value of a base field (property).
   *
   * @param string $property
   *   The name of the entity property.
   *
   * @return \Drupal\Core\Database\StatementInterface|null
   *   A prepared statement, or NULL if the query is not valid.
   */
  public function loadPropertySet($property) {
    $definitions = $this->entityManager->getBaseFieldDefinitions($this->entityTypeId);
    if (array_key_exists($property, $definitions)) {
      $query = $this->database->select($this->entityType->getBaseTable(), 'base');
      $query->fields('fa', array('id', $property));
      $stored = $query->execute();
      return $stored;
    }
    else {
      throw new InvalidQueryException('Failed to load Property Set. %property: Not a valid property of fa_form', ['%property' => $property]);
    }
  }

}